## Version 0.0.17

This new version includes updates to the versions of bokeh used in the project. The bokeh version has been pinned to ensure compatibility and stability of the project.

### New Features

- No new features were added in this version.

### Bug Fixes

- The versions of bokeh used in the project have been updated to ensure compatibility and stability. (96a89e) (Eric Ma)

### Deprecations

- The bokeh version has been pinned to less than or equal to 3.1.0 to prevent potential issues with future versions. (2a93d9) (Eric Ma)
